@@ -3,7 +3,7 @@ use warnings;
 
 package WebService::TVDB;
 {
-  $WebService::TVDB::VERSION = '1.120600';
+  $WebService::TVDB::VERSION = '1.120740';
 }
 
 # ABSTRACT: Interface to http://thetvdb.com/
@@ -11,6 +11,7 @@ package WebService::TVDB;
 use WebService::TVDB::Languages qw($languages);
 use WebService::TVDB::Series;
 use WebService::TVDB::Mirror;
+use WebService::TVDB::Util qw(get_api_key_from_file);
 
 use LWP::Simple ();
 use XML::Simple qw(:strict);
@@ -32,7 +33,7 @@ sub new {
     unless ( $self->api_key ) {
         require File::HomeDir;
         $self->{api_key} =
-          _get_api_key_from_file( File::HomeDir->my_home . API_KEY_FILE );
+          get_api_key_from_file( File::HomeDir->my_home . API_KEY_FILE );
         die 'Can\'t find API key' unless $self->api_key;
     }
 
@@ -96,23 +97,6 @@ sub _load_mirros {
     $self->{mirrors} = $mirrors;
 }
 
-# slurps the api_key from file
-sub _get_api_key_from_file {
-    my ($file) = @_;
-
-    return do {
-        local $/ = undef;
-        open my $fh, "<", $file
-          or die "could not open $file: $!";
-        my $doc = <$fh>;
-
-        # ensure there are no carriage returns
-        $doc =~ s/(\r|\n)//g;
-
-        return $doc;
-    };
-}
-
 1;
 
 
@@ -125,7 +109,7 @@ WebService::TVDB - Interface to http://thetvdb.com/
 
 =head1 VERSION
 
-version 1.120600
+version 1.120740
 
 =head1 SYNOPSIS
 
